@@ -1,6 +1,4 @@
 /*
-  $Header: /cvs/src/mairix/mairix.c,v 1.21 2004/01/11 23:50:41 richard Exp $
-
   mairix - message index builder and finder for maildir folders.
 
  **********************************************************************
@@ -23,6 +21,7 @@
  */
 
 #include "mairix.h"
+#include "version.h"
 #include <assert.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -155,7 +154,7 @@ static void parse_rc_file(char *name)/*{{{*/
     /* Discard blank lines */
     all_blank = 1;
     for (p=line; *p; p++) {
-      if (!isspace(*p)) {
+      if (!isspace(*(unsigned char *)p)) {
         all_blank = 0;
         break;
       }
@@ -286,33 +285,6 @@ volatile void out_of_mem(char *file, int line, size_t size)/*{{{*/
   exit(2); 
 }
 /*}}}*/
-static char *get_version(void)/*{{{*/
-{
-  static char buffer[256];
-  static char cvs_version[] = "$Name: V0_14_1 $";
-  char *p, *q;
-  for (p=cvs_version; *p; p++) {
-    if (*p == ':') {
-      p++;
-      break;
-    }
-  }
-  while (isspace(*p)) p++;
-  if (*p == '$') {
-    strcpy(buffer, "development version");
-  } else {
-    for (q=buffer; *p && *p != '$'; p++) {
-      if (!isspace(*p)) {
-        if (*p == '_') *q++ = '.';
-        else *q++ = *p;
-      }
-    }
-    *q = 0;
-  }
-
-  return buffer;
-}
-/*}}}*/
 static void print_copyright(void)/*{{{*/
 {
   fprintf(stderr,
@@ -320,7 +292,7 @@ static void print_copyright(void)/*{{{*/
           "mairix comes with ABSOLUTELY NO WARRANTY.\n"
           "This is free software, and you are welcome to redistribute it\n"
           "under certain conditions; see the GNU General Public License for details.\n\n",
-          get_version());
+          PROGRAM_VERSION);
 }
 /*}}}*/
 static void usage(void)/*{{{*/
@@ -401,6 +373,7 @@ int main (int argc, char **argv)/*{{{*/
   int any_purges = 0;
   int do_help = 0;
   int do_raw_output = 0;
+  int do_dump = 0;
 
   setlocale(LC_CTYPE, "");
 
@@ -421,6 +394,8 @@ int main (int argc, char **argv)/*{{{*/
       arg_mfolder = *argv;
     } else if (!strcmp(*argv, "-p") || !strcmp(*argv, "--purge")) {
       do_purge = 1;
+    } else if (!strcmp(*argv, "-d") || !strcmp(*argv, "--dump")) {
+      do_dump = 1;
     } else if (!strcmp(*argv, "-r") || !strcmp(*argv, "--raw-output")) {
       do_raw_output = 1;
     } else if (!strcmp(*argv, "-v") || !strcmp(*argv, "--verbose")) {
@@ -497,7 +472,11 @@ int main (int argc, char **argv)/*{{{*/
     output_folder_type = FT_RAW;
   }
 
-  if (do_search) {
+  if (do_dump) {
+    dump_database(database_path);
+    return 0;
+
+  } else if (do_search) {
     if (!mfolder) {
       if (output_folder_type != FT_RAW) {
         fprintf(stderr, "No mfolder/MAIRIX_MFOLDER set\n");
