@@ -1,6 +1,4 @@
 /*
-  $Header: /cvs/src/mairix/mbox.c,v 1.19 2004/01/11 23:46:54 richard Exp $
-
   mairix - message index builder and finder for maildir folders.
 
  **********************************************************************
@@ -786,11 +784,11 @@ void build_mbox_lists(struct database *db, const char *folder_base, const char *
         mb->n_old_msgs_valid = mb->n_msgs;
       } else {
         unsigned char *va;
-        size_t len;
+        int len;
         create_ro_mapping(mb->path, &va, &len);
         if (va) {
           rescan_mbox(mb, va, len);
-          munmap(va, len);
+          munmap(va, (size_t) len);
         } else {
           /* Treat as dead mbox */
           deaden_mbox(mb);
@@ -809,7 +807,7 @@ int add_mbox_messages(struct database *db)/*{{{*/
   int i, j;
   int any_new = 0;
   unsigned char *va;
-  size_t valen;
+  int valen;
 
   for (i=0; i<db->n_mboxen; i++) {
     struct mbox *mb = &db->mboxen[i];
@@ -838,19 +836,19 @@ int add_mbox_messages(struct database *db)/*{{{*/
       r8 = data_to_rfc822(va + start, len);
       if (r8) {
         if (verbose) {
-          printf("Scanning %s[%d] at [%d,%d)\n", mb->path, j, (int)start, (int)start + len);
+          printf("Scanning %s[%d] at [%d,%d)\n", mb->path, j, (int)start, (int)(start + len));
         }
         db->msgs[n].date = r8->hdrs.date;
         tokenise_message(n, db, r8);
         free_rfc822(r8);
       } else {
-        printf("Message in %s at [%d,%d) is misformatted\n", mb->path, (int)start, (int)start + len);
+        printf("Message in %s at [%d,%d) is misformatted\n", mb->path, (int)start, (int)(start + len));
       }
 
       ++db->n_msgs;
       any_new = 1;
     }
-    if (va) munmap(va, valen);
+    if (va) munmap(va, (size_t) valen);
   }
   return any_new;
 }
